@@ -2,11 +2,12 @@
 
 set tclsh_path SET_YOUR_TCLSH_PATH
 set buildpath Win32/Debug
-set tcllib libdb_tcl48d.dll
+set tcllib libdb_tcl53d.dll
 
 set src_root ..
-set test_path ../test
+set test_path ../test/tcl
 set je_root ../../je
+set tcl_utils ../test/tcl_utils
 
 global testdir
 set testdir ./TESTDIR
@@ -17,6 +18,7 @@ global util_path
 global is_freebsd_test
 global is_hp_test
 global is_linux_test
+global is_osx_test
 global is_qnx_test
 global is_sunos_test
 global is_windows_test
